@@ -1,5 +1,4 @@
-from jax.numpy import dot, ones_like, eye, square
-from jax.numpy import sum as arraysum
+from jax.numpy import dot, square
 from jax.numpy.linalg import cholesky
 from jax.scipy.linalg import solve_triangular
 from .util import stabilize, DEFAULT_JITTER
@@ -82,9 +81,9 @@ def _full_conditional_mean_y(
     :rtype: function
     """
     if len(x.shape) < 2:
-        x = x[:, none]
+        x = x[:, None]
     if len(Xnew.shape) < 2:
-        Xnew = Xnew[:, none]
+        Xnew = Xnew[:, None]
     sigma2 = square(sigma)
     K = cov_func(x, x)
     sigma2 = max(sigma2, jitter)
